(in-ns-decl? form)Returns true if form is a (in-ns ...) declaration.
Returns true if form is a (in-ns ...) declaration.
(read-in-ns-decl rdr)Attempts to read a (in-ns ...) declaration from a java.io.PushbackReader. Returns nil if it fails or if a in-ns declaration cannot be found. The in-ns declaration must be the first Clojure form in the file, except for (comment ...) forms
Attempts to read a (in-ns ...) declaration from a java.io.PushbackReader. Returns nil if it fails or if a in-ns declaration cannot be found. The in-ns declaration must be the first Clojure form in the file, except for (comment ...) forms
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |